@@ -100,6 +100,11 @@ def get_STATE_info(self, field='state', machine=None):
             """
             return machine.get_state_groups(getattr(self, field))
 
+        @property
+        def initial(si_self):
+            return self.state == machine.initial_state
+
+        @property
         def possible_transitions(si_self):
             """
             Return list of transitions which can be made from the current
